@@ -24,8 +24,6 @@ class CControllerUserCreate extends CControllerUserUpdateGeneral {
 	protected function checkInput() {
 		$locales = array_keys(getLocales());
 		$locales[] = LANG_DEFAULT;
-		$timezones = DateTimeZone::listIdentifiers();
-		$timezones[] = TIMEZONE_DEFAULT;
 		$themes = array_keys(APP::getThemes());
 		$themes[] = THEME_DEFAULT;
 
@@ -38,7 +36,7 @@ class CControllerUserCreate extends CControllerUserUpdateGeneral {
 			'user_groups' =>	'required|array_id|not_empty',
 			'medias' =>			'array',
 			'lang' =>			'db users.lang|in '.implode(',', $locales),
-			'timezone' =>		'db users.timezone|in '.implode(',', $timezones),
+			'timezone' =>		'db users.timezone|in '.implode(',', $this->timezones),
 			'theme' =>			'db users.theme|in '.implode(',', $themes),
 			'autologin' =>		'db users.autologin|in 0,1',
 			'autologout' =>		'db users.autologout|not_empty',
