@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -70,7 +70,8 @@ class CControllerWidgetDiscoveryView extends CControllerWidget {
 			'error' => $error,
 			'user' => [
 				'debug_mode' => $this->getDebugMode()
-			]
+			],
+			'allowed_ui_discovery' => CWebUser::checkAccess(CRoleHelper::UI_MONITORING_DISCOVERY)
 		]));
 	}
 }
