@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2017 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -287,7 +287,7 @@ class CGraph extends CGraphGeneral {
 
 		$sqlParts = $this->applyQueryOutputOptions($this->tableName(), $this->tableAlias(), $options, $sqlParts);
 		$sqlParts = $this->applyQuerySortOptions($this->tableName(), $this->tableAlias(), $options, $sqlParts);
-		$dbRes = DBselect($this->createSelectQueryFromParts($sqlParts), $sqlParts['limit']);
+		$dbRes = DBselect(self::createSelectQueryFromParts($sqlParts), $sqlParts['limit']);
 		while ($graph = DBfetch($dbRes)) {
 			if ($options['countOutput']) {
 				if ($options['groupCount']) {
@@ -514,72 +514,53 @@ class CGraph extends CGraphGeneral {
 	 * Delete graphs.
 	 *
 	 * @param array $graphids
-	 * @param bool  $nopermissions
 	 *
 	 * @return array
 	 */
-	public function delete(array $graphids, $nopermissions = false) {
-		if (empty($graphids)) {
-			self::exception(ZBX_API_ERROR_PARAMETERS, _('Empty input parameter.'));
-		}
+	public function delete(array $graphids) {
+		$this->validateDelete($graphids, $db_graphs);
 
-		$delGraphs = $this->get([
-			'output' => API_OUTPUT_EXTEND,
-			'graphids' => $graphids,
-			'editable' => true,
-			'preservekeys' => true,
-			'selectHosts' => ['name']
-		]);
+		CGraphManager::delete($graphids);
 
-		if (!$nopermissions) {
-			foreach ($graphids as $graphid) {
-				if (!isset($delGraphs[$graphid])) {
-					self::exception(ZBX_API_ERROR_PERMISSIONS, _('You do not have permission to perform this operation.'));
-				}
-
-				$delGraph = $delGraphs[$graphid];
-
-				if ($delGraph['templateid'] != 0) {
-					self::exception(ZBX_API_ERROR_PERMISSIONS, _('Cannot delete templated graphs.'));
-				}
-			}
-		}
-
-		$parentGraphids = $graphids;
-		do {
-			$dbGraphs = DBselect('SELECT g.graphid FROM graphs g WHERE '.dbConditionInt('g.templateid', $parentGraphids));
-			$parentGraphids = [];
-			while ($dbGraph = DBfetch($dbGraphs)) {
-				$parentGraphids[] = $dbGraph['graphid'];
-				$graphids[] = $dbGraph['graphid'];
-			}
-		} while (!empty($parentGraphids));
-
-		$graphids = array_unique($graphids);
-
-		DB::delete('screens_items', [
-			'resourceid' => $graphids,
-			'resourcetype' => SCREEN_RESOURCE_GRAPH
-		]);
-
-		DB::delete('profiles', [
-			'idx' => 'web.favorite.graphids',
-			'source' => 'graphid',
-			'value_id' => $graphids
-		]);
-
-		DB::delete('graphs', [
-			'graphid' => $graphids
-		]);
-
-		foreach ($delGraphs as $graph) {
-			$host = reset($graph['hosts']);
-			info(_s('Deleted: Graph "%1$s" on "%2$s".', $graph['name'], $host['name']));
-		}
+		$this->addAuditBulk(AUDIT_ACTION_DELETE, AUDIT_RESOURCE_GRAPH, $db_graphs);
 
 		return ['graphids' => $graphids];
 	}
 
+	/**
+	 * Validates the input parameters for the delete() method.
+	 *
+	 * @param array $graphids   [IN/OUT]
+	 * @param array $db_graphs  [OUT]
+	 *
+	 * @throws APIException if the input is invalid.
+	 */
+	private function validateDelete(array &$graphids, array &$db_graphs = null) {
+		$api_input_rules = ['type' => API_IDS, 'flags' => API_NOT_EMPTY, 'uniq' => true];
+		if (!CApiInputValidator::validate($api_input_rules, $graphids, '/', $error)) {
+			self::exception(ZBX_API_ERROR_PARAMETERS, $error);
+		}
+
+		$db_graphs = $this->get([
+			'output' => ['graphid', 'name', 'templateid'],
+			'graphids' => $graphids,
+			'editable' => true,
+			'preservekeys' => true
+		]);
+
+		foreach ($graphids as $graphid) {
+			if (!array_key_exists($graphid, $db_graphs)) {
+				self::exception(ZBX_API_ERROR_PERMISSIONS,
+					_('No permissions to referred object or it does not exist!')
+				);
+			}
+
+			if ($db_graphs[$graphid]['templateid'] != 0) {
+				self::exception(ZBX_API_ERROR_PARAMETERS, _('Cannot delete templated graph.'));
+			}
+		}
+	}
+
 	protected function addRelatedObjects(array $options, array $result) {
 		$result = parent::addRelatedObjects($options, $result);
 
@@ -602,10 +583,12 @@ class CGraph extends CGraphGeneral {
 		if ($options['selectDiscoveryRule'] !== null) {
 			$dbRules = DBselect(
 				'SELECT id.parent_itemid,gd.graphid'.
-					' FROM graph_discovery gd,item_discovery id,graphs_items gi'.
+					' FROM graph_discovery gd,item_discovery id,graphs_items gi,items i'.
 					' WHERE '.dbConditionInt('gd.graphid', $graphids).
 					' AND gd.parent_graphid=gi.graphid'.
-					' AND gi.itemid=id.itemid'
+						' AND gi.itemid=id.itemid'.
+						' AND id.parent_itemid=i.itemid'.
+						' AND i.flags='.ZBX_FLAG_DISCOVERY_RULE
 			);
 			$relationMap = new CRelationMap();
 			while ($relation = DBfetch($dbRules)) {
