@@ -838,7 +838,7 @@ class CConfigurationExportBuilder {
 
 		foreach ($groupLinks as $groupLink) {
 			$result[] = [
-				'group' => $groupLink['groupid'],
+				'group' => $groupLink['groupid']
 			];
 		}
 
