@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -19,12 +19,17 @@
 **/
 
 
+/**
+ * @var CView $this
+ */
+
 require_once dirname(__FILE__).'/js/configuration.discovery.edit.js.php';
 
 $widget = (new CWidget())->setTitle(_('Discovery rules'));
 
-// create form
+// Create form.
 $discoveryForm = (new CForm())
+	->setId('discoveryForm')
 	->setName('discoveryForm')
 	->setAttribute('aria-labeledby', ZBX_STYLE_PAGE_TITLE)
 	->addVar('form', $this->data['form']);
@@ -32,7 +37,7 @@ if (!empty($this->data['druleid'])) {
 	$discoveryForm->addVar('druleid', $this->data['druleid']);
 }
 
-// create form list
+// Create form list.
 $discoveryFormList = (new CFormList())
 	->addRow(
 		(new CLabel(_('Name'), 'name'))->setAsteriskMark(),
@@ -42,7 +47,7 @@ $discoveryFormList = (new CFormList())
 			->setAttribute('autofocus', 'autofocus')
 	);
 
-// append proxy to form list
+// Append proxy to form list.
 $proxyComboBox = (new CComboBox('proxy_hostid', $this->data['drule']['proxy_hostid']))
 	->addItem(0, _('No proxy'));
 foreach ($this->data['proxies'] as $proxy) {
@@ -67,10 +72,13 @@ $discoveryFormList->addRow(
 	(new CDiv(
 		(new CTable())
 			->setAttribute('style', 'width: 100%;')
+			->setHeader([_('Type'), _('Actions')])
 			->setFooter(
 				(new CRow(
 					(new CCol(
-						(new CButton('newCheck', _('New')))->addClass(ZBX_STYLE_BTN_LINK)
+						(new CSimpleButton(_('Add')))
+							->setAttribute('data-action', 'add')
+							->addClass(ZBX_STYLE_BTN_LINK)
 					))->setColSpan(2)
 				))->setId('dcheckListFooter')
 			)
@@ -80,7 +88,7 @@ $discoveryFormList->addRow(
 		->setId('dcheckList')
 );
 
-// append uniqueness criteria to form list
+// Append uniqueness criteria to form list.
 $discoveryFormList->addRow(_('Device uniqueness criteria'),
 	(new CDiv(
 		(new CRadioButtonList('uniqueness_criteria', (int) $this->data['drule']['uniqueness_criteria']))
@@ -91,7 +99,7 @@ $discoveryFormList->addRow(_('Device uniqueness criteria'),
 		->addClass(ZBX_STYLE_TABLE_FORMS_SEPARATOR)
 );
 
-// append host source to form list
+// Append host source to form list.
 $discoveryFormList->addRow(_('Host name'),
 	(new CDiv(
 		(new CRadioButtonList('host_source', $this->data['drule']['host_source']))
@@ -103,7 +111,7 @@ $discoveryFormList->addRow(_('Host name'),
 		->addClass(ZBX_STYLE_TABLE_FORMS_SEPARATOR)
 );
 
-// append name source to form list
+// Append name source to form list.
 $discoveryFormList->addRow(_('Visible name'),
 	(new CDiv(
 		(new CRadioButtonList('name_source', $this->data['drule']['name_source']))
@@ -116,19 +124,18 @@ $discoveryFormList->addRow(_('Visible name'),
 		->addClass(ZBX_STYLE_TABLE_FORMS_SEPARATOR)
 );
 
-// append status to form list
+// Append status to form list.
 $status = (empty($this->data['druleid']) && empty($this->data['form_refresh']))
 	? true
 	: ($this->data['drule']['status'] == DRULE_STATUS_ACTIVE);
 
 $discoveryFormList->addRow(_('Enabled'), (new CCheckBox('status'))->setChecked($status));
 
-// append tabs to form
+// Append tabs to form.
 $discoveryTabs = (new CTabView())->addTab('druleTab', _('Discovery rule'), $discoveryFormList);
 
-// append buttons to form
-if (isset($this->data['druleid']))
-{
+// Append buttons to form.
+if (isset($this->data['druleid'])) {
 	$discoveryTabs->setFooter(makeFormFooter(
 		new CSubmit('update', _('Update')),
 		[
@@ -149,4 +156,4 @@ $discoveryForm->addItem($discoveryTabs);
 
 $widget->addItem($discoveryForm);
 
-return $widget;
+$widget->show();
