@@ -19,6 +19,10 @@
 **/
 
 
+/**
+ * @var CView $this
+ */
+
 require_once dirname(__FILE__).'/js/configuration.triggers.edit.js.php';
 
 $triggersWidget = (new CWidget())
@@ -27,6 +31,7 @@ $triggersWidget = (new CWidget())
 
 // create form
 $triggersForm = (new CForm())
+	->setId('triggers-prototype-form')
 	->setName('triggersForm')
 	->setAttribute('aria-labeledby', ZBX_STYLE_PAGE_TITLE)
 	->addVar('form', $data['form'])
@@ -44,11 +49,11 @@ if ($data['triggerid'] !== null) {
 
 if ($data['limited']) {
 	$triggersForm
-		->addVar('opdata', $data['opdata'])
-		->addVar('recovery_mode', $data['recovery_mode'])
-		->addVar('type', $data['type'])
-		->addVar('correlation_mode', $data['correlation_mode'])
-		->addVar('manual_close', $data['manual_close']);
+		->addItem((new CVar('opdata', $data['opdata']))->removeId())
+		->addItem((new CVar('recovery_mode', $data['recovery_mode']))->removeId())
+		->addItem((new CVar('type', $data['type']))->removeId())
+		->addItem((new CVar('correlation_mode', $data['correlation_mode']))->removeId())
+		->addItem((new CVar('manual_close', $data['manual_close']))->removeId());
 }
 
 // create form list
@@ -64,6 +69,13 @@ $triggersFormList
 			->setAriaRequired()
 			->setAttribute('autofocus', 'autofocus')
 	)
+	->addRow(
+		(new CLabel(_('Event name'), 'event_name')),
+		(new CTextAreaFlexible('event_name', $data['event_name']))
+			->setReadonly($data['limited'])
+			->setMaxlength(DB::getFieldLength('triggers', 'event_name'))
+			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
+	)
 	->addRow(
 		new CLabel(_('Operational data'), 'opdata'),
 		(new CTextBox('opdata', $data['opdata'], $data['limited']))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
@@ -75,11 +87,11 @@ $triggersFormList
 
 // append expression to form list
 if ($data['expression_field_readonly']) {
-	$triggersForm->addVar('expression', $data['expression']);
+	$triggersForm->addItem((new CVar('expression', $data['expression']))->removeId());
 }
 
 if ($data['recovery_expression_field_readonly']) {
-	$triggersForm->addVar('recovery_expression', $data['recovery_expression']);
+	$triggersForm->addItem((new CVar('recovery_expression', $data['recovery_expression']))->removeId());
 }
 
 $popup_options = [
@@ -89,14 +101,13 @@ $popup_options = [
 	'dstfld1' => $data['expression_field_name'],
 	'parent_discoveryid' => $data['parent_discoveryid']
 ];
-if ($data['groupid'] && $data['hostid']) {
-	$popup_options['groupid'] = $data['groupid'];
+if ($data['hostid']) {
 	$popup_options['hostid'] = $data['hostid'];
 }
 $add_expression_button = (new CButton('insert', ($data['expression_constructor'] == IM_TREE) ? _('Edit') : _('Add')))
 	->addClass(ZBX_STYLE_BTN_GREY)
 	->onClick('return PopUp("popup.triggerexpr",jQuery.extend('.
-		CJs::encodeJson($popup_options).
+		json_encode($popup_options).
 			',{expression: jQuery(\'[name="'.$data['expression_field_name'].'"]\').val()}), null, this);'
 	)
 	->removeId();
@@ -223,13 +234,13 @@ if ($data['expression_constructor'] == IM_TREE) {
 							->setChecked($i == 0)
 							->onClick('check_target(this, '.TRIGGER_EXPRESSION.');')
 						: null,
-					$e['list'],
+					(new CDiv($e['list']))->addClass(ZBX_STYLE_WORDWRAP),
 					!$data['limited']
 						? (new CCol(
 							(new CSimpleButton(_('Remove')))
 								->addClass(ZBX_STYLE_BTN_LINK)
 								->onClick('javascript:'.
-									' if (confirm('.CJs::encodeJson(_('Delete expression?')).')) {'.
+									' if (confirm('.json_encode(_('Delete expression?')).')) {'.
 										' delete_expression("'.$e['id'] .'", '.TRIGGER_EXPRESSION.');'.
 										' document.forms["'.$triggersForm->getName().'"].submit();'.
 									' }'
@@ -291,7 +302,7 @@ $add_recovery_expression_button = (new CButton('insert',
 	)
 	->addClass(ZBX_STYLE_BTN_GREY)
 	->onClick('return PopUp("popup.triggerexpr",jQuery.extend('.
-		CJs::encodeJson([
+		json_encode([
 			'srctbl' => $data['recovery_expression_field_name'],
 			'srcfld1' => $data['recovery_expression_field_name'],
 			'dstfrm' => $triggersForm->getName(),
@@ -425,7 +436,7 @@ if ($data['recovery_expression_constructor'] == IM_TREE) {
 							(new CSimpleButton(_('Remove')))
 								->addClass(ZBX_STYLE_BTN_LINK)
 								->onClick('javascript:'.
-									' if (confirm('.CJs::encodeJson(_('Delete expression?')).')) {'.
+									' if (confirm('.json_encode(_('Delete expression?')).')) {'.
 										' delete_expression("'.$e['id'] .'", '.TRIGGER_RECOVERY_EXPRESSION.');'.
 										' document.forms["'.$triggersForm->getName().'"].submit();'.
 									' }'
@@ -518,7 +529,12 @@ $triggersFormList
 			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 			->setMaxlength(DB::getFieldLength('triggers', 'comments'))
 	)
-	->addRow(_('Create enabled'), (new CCheckBox('status'))->setChecked($status));
+	->addRow(_('Create enabled'), (new CCheckBox('status'))->setChecked($status))
+	->addRow(_('Discover'),
+		(new CCheckBox('discover', ZBX_PROTOTYPE_DISCOVER))
+			->setChecked($data['discover'] == ZBX_PROTOTYPE_DISCOVER)
+			->setUncheckedValue(ZBX_PROTOTYPE_NO_DISCOVER)
+	);
 
 // append tabs to form
 $triggersTab = new CTabView();
@@ -527,22 +543,21 @@ if (!$data['form_refresh']) {
 }
 $triggersTab->addTab('triggersTab',	_('Trigger prototype'), $triggersFormList);
 
-/*
- * Tags tab
- */
-$tags_view = new CView('configuration.tags.tab', [
-	'source' => 'trigger_prototype',
-	'tags' => $data['tags'],
-	'show_inherited_tags' => $data['show_inherited_tags'],
-	'readonly' => false
-]);
-$triggersTab->addTab('tags-tab', _('Tags'), $tags_view->render());
+// tags
+$triggersTab->addTab('tags-tab', _('Tags'), new CPartial('configuration.tags.tab', [
+		'source' => 'trigger_prototype',
+		'tags' => $data['tags'],
+		'show_inherited_tags' => $data['show_inherited_tags'],
+		'readonly' => false
+	]), TAB_INDICATOR_TAGS
+);
 
 /*
  * Dependencies tab
  */
 $dependenciesFormList = new CFormList('dependenciesFormList');
 $dependenciesTable = (new CTable())
+	->setId('dependency-table')
 	->setAttribute('style', 'width: 100%;')
 	->setHeader([_('Name'), _('Action')]);
 
@@ -583,7 +598,7 @@ $dependenciesFormList->addRow(_('Dependencies'),
 		new CHorList([
 			(new CButton('add_dep_trigger', _('Add')))
 				->onClick('return PopUp("popup.generic",'.
-					CJs::encodeJson([
+					json_encode([
 						'srctbl' => 'triggers',
 						'srcfld1' => 'triggerid',
 						'reference' => 'deptrigger',
@@ -591,14 +606,13 @@ $dependenciesFormList->addRow(_('Dependencies'),
 						'with_triggers' => '1',
 						'normal_only' => '1',
 						'noempty' => '1',
-						'hostid' => $data['hostid'],
-						'groupid' => $data['groupid']
+						'hostid' => $data['hostid']
 					]).', null, this);'
 				)
 				->addClass(ZBX_STYLE_BTN_LINK),
 			(new CButton('add_dep_trigger_prototype', _('Add prototype')))
 				->onClick('return PopUp("popup.generic",'.
-					CJs::encodeJson([
+					json_encode([
 						'srctbl' => 'trigger_prototypes',
 						'srcfld1' => 'triggerid',
 						'reference' => 'deptrigger',
@@ -612,7 +626,7 @@ $dependenciesFormList->addRow(_('Dependencies'),
 		->addClass(ZBX_STYLE_TABLE_FORMS_SEPARATOR)
 		->setAttribute('style', 'min-width: '.ZBX_TEXTAREA_BIG_WIDTH.'px;')
 );
-$triggersTab->addTab('dependenciesTab', _('Dependencies'), $dependenciesFormList);
+$triggersTab->addTab('dependenciesTab', _('Dependencies'), $dependenciesFormList, TAB_INDICATOR_DEPENDENCY);
 
 // append buttons to form
 if (!empty($data['triggerid'])) {
@@ -644,4 +658,4 @@ $triggersForm->addItem($triggersTab);
 
 $triggersWidget->addItem($triggersForm);
 
-return $triggersWidget;
+$triggersWidget->show();
